//MIRS1404_Arduinoプログラム
//射出機構・音声出力・LED装飾プログラム

#include <Wire.h>  //RS232Cの使用

#define LED1 8
#define LED2 9
#define LED3 10

//変数定義
//シリアル通信からの信号受信
char input;

//射出機構部
const int PWM_mot = 6;
const int motorA = 5;
const int motorB = 4;

//音声出力部


//LED装飾部

int led[] = {  
  33,35,37,39,41,43,45,47,49};
int layer[] = {  
  27,29,31};
int cycletime=200;   //コマ間の時間1000ms

//template
int TEMP_LED[]={
  0x000, 0x000, 0x000}; //左からトップ層ミドル層ボトム層
//template


int ANIM_1_TOP[]={
  0x124, 0x092, 0x049, 0x049, 0x092,0x124,0x124,0x1C0,0x038,0x007,0x007,0x038,0x1C0,0x1C0,
  0x1ff,0x000,0x000,0x000,0x000,0x1ff,0x1ff
};
int ANIM_1_MID[]={
  0x124, 0x092, 0x049, 0x049, 0x092,0x124,0x124,0x1C0,0x038,0x007,0x007,0x038,0x1C0,0x1C0,
  0x000,0x1ff,0x000,0x000,0x1ff,0x000,0x000
};
int ANIM_1_BOT[]={
  0x124, 0x092, 0x049, 0x049, 0x092,0x124,0x124,0x1C0,0x038,0x007,0x007,0x038,0x1C0,0x1C0,
  0x000,0x000,0x1ff,0x1ff,0x000,0x000,0x000
};
int ANIM_2_TOP[]={
  0x111,0x092,0x054,0x038,0x111,0x092,0x054,0x038,0x111,0x000,0x049,0x092,
  0x124,0x000,0x049,0x092,0x124,0x000,0x000,0x007,0x038,0x1c0,0x000,0x007,0x038,0x1c0,0x000};
int ANIM_2_MID[]={
  0x111,0x092,0x054,0x038,0x111,0x092,0x054,0x038,0x111,0x1ff,0x098,0x092,
  0x092,0x1ff,0x098,0x092,0x092,0x1ff,0x1ff,0x038,0x038,0x038,0x1ff,0x038,0x038,0x038,0x1ff};
int ANIM_2_BOT[]={
  0x111,0x092,0x054,0x038,0x111,0x092,0x054,0x038,0x111,0x000,0x124,0x092,
  0x049,0x000,0x124,0x092,0x049,0x000,0x000,0x1c0,0x038,0x007,0x000,0x1c0,0x038,0x007,0x000};

void AllOFF(){
  for(int i=0;i<(sizeof(led)/sizeof(int));i++){   //sizeof()はarray.length
    digitalWrite(led[i], LOW);
  }
  for(int i=0;i<(sizeof(layer)/sizeof(int));i++){  
    digitalWrite(layer[i], HIGH);
  }
}
void DynaDrive(int pat[]){ //1msで上下のレイヤーを点灯消灯  配列の先頭のポインタが与えられる
  for(int n=0; n<cycletime/3;n++){
    for(int L=0; L < (sizeof(layer)/sizeof(int)); L++){
      for(int temp=0; temp<(sizeof(led)/sizeof(int)); temp++){
        if(bitRead(pat[L],temp) == B01){
          digitalWrite(led[temp],HIGH);
        }
        else{
          digitalWrite(led[temp],LOW);
        }
      }
      digitalWrite(layer[L],LOW);
      delayMicroseconds(500);
      digitalWrite(layer[L],HIGH);
      delayMicroseconds(500);
    }
  }
}


//ピンセットアップ
void setup(){
  for(int i=0;i<(sizeof(led)/sizeof(int));i++){  
    pinMode(led[i], OUTPUT);
  }     
  for(int i=0;i<(sizeof(layer)/sizeof(int));i++){  
    pinMode(layer[i], OUTPUT);
  } 
  AllOFF(); 
  // シリアルポートを9600 bps[ビット/秒]で初期化
  Serial.begin(9600);
  Serial.println("start");
  
  pinMode(LED1, OUTPUT);
  pinMode(LED2, OUTPUT);
  pinMode(LED3, OUTPUT);
  
  pinMode(motorA,OUTPUT); //射出モーター専用信号用ピン
  pinMode(motorB,OUTPUT); //射出モーター専用信号用ピン
  
  Wire.begin();
}


//Arduinoのメイン関数
void loop(){
 //Ubuntuからの信号受信
 input = Serial.read();  //Ubuntuから信号受信
  
  if(input != -1){
    //この中に射出、音声、LEDを追加していく
    switch(input){
      
      //******射出機構プログラム until a to d ******
      case 'a':
        Serial.println("Syasyutu Go!");
        pair_eyes_go(-150, 1800);
        motor_stop(1000);
        Serial.println("a:break");
        break;
        
      case 'b':  //射出機構収納
        Serial.println("Syasyutu Back!");
        pair_eyes_back(-150, 1600);
        motor_stop(1000);
        Serial.println("b:break");
        break;
        
      case 'c':  //射出機構ストップ
        Serial.println("Syasyutu stop!");
        motor_stop(2000);
        Serial.println("c:break");
        break;
        
      case 'd':  //射出初期設定
        Serial.println("Syasyutu syokiset!");
        pair_eyes_go(-150, 1150);
        motor_stop(2000);
        Serial.println("d:break");
        break;
       
      //***************************************
      
      
      //******LEDプログラム until e to m ******
      case 'e':
        Serial.print("LED1 ON\n");
        digitalWrite(LED1, HIGH);
        break;
      
      case 'f':
        Serial.print("LED1 OFF\n");
        digitalWrite(LED1, LOW);
        break;
      
      case 'g':
        Serial.print("LED2 ON\n");
        digitalWrite(LED2, HIGH);
        break;
      
      case 'h':
        Serial.print("LED2 OFF\n");
        digitalWrite(LED2, LOW);
        break;
      
      case 'i':
        Serial.print("LED3 ON\n");
        digitalWrite(LED3, HIGH);
        break;
      
      case 'j':
        Serial.print("LED3 OFF\n");
        digitalWrite(LED3, LOW);
        break;
      
      case 'k':
        Serial.print("ALL LED ON\n");
        digitalWrite(LED1, HIGH);
        digitalWrite(LED2, HIGH);
        digitalWrite(LED3, HIGH);
        break;
      
      //******音声プログラム until i to z and A to I******
      
      case 'l':
        Serial.print("satueisuruyo\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("satueisuruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'm':
        Serial.print("ganbaruyo\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("ganbaruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'n':
        Serial.print("konnitiwa\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("konnitiwa");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'o':
        Serial.print("start\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("syuppatusuruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'p':
        Serial.print("heya1\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("itibannoheyanimukauyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
        
      case 'q':
        Serial.print("migi\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("hidarinimagaruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'r':
        Serial.print("hidari\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("miginimagaruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 's':
        Serial.print("massugu\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("tyokusinsuruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 't':
        Serial.print("migikaiten\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("miginikaitensuruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'u':
        Serial.print("hidarikaiten\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("hidarinikaitensuruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'v':
        Serial.print("syasyutu\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("syasyutudo--n");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'w':
        Serial.print("simau\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("simauyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'x':
        Serial.print("doko\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("kaitoudokokana--");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'y':
        Serial.print("mikke\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("kaitouwomituketayo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'z':
        Serial.print("zyunnkai\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("zyunkaityu---");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      //*****************大文字*****************
      case 'A':
        Serial.print("tukareta\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("zyunkaitukareta-");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'B':
        Serial.print("kyuukei\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("kyuukeisuruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'C':
        Serial.print("oiru\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("oirunomitaina");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'D':
        Serial.print("tyuuou\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("mappunotyuuouniikuyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'E':
        Serial.print("hu-n\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("bu-----n");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'F':
        Serial.print("tweet\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("tui-tositayo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'G':
        Serial.print("LED\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("erui-dhi-pikapika");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'H':
        Serial.print("kakuho\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("kaitoukakuho");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'I':
        Serial.print("baibai\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("kyougigasyuuryousitayo baibai");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
        
      case 'J':
        Serial.print("heya2\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("nibannoheyanimukauyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'K':
        Serial.print("heya3\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("sanbannoheyanimukauyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'L':
        Serial.print("heya4\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("yonbannoheyanimukauyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
        
      case 'M':
        Serial.print("okure\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("yoteiyoriokureteiruyo;tehepero");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'N':
        Serial.print("yoteidoori\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("yoteidooridayo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
        
      case 'O':
        Serial.print("1ppun\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("ippunkeikadayo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'P':
        Serial.print("2hun\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("nihunkeikadayo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'Q':
        Serial.print("3hun\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("sanhunkeikadayo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'R':
        Serial.print("4hun\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("yonhunkeikadayo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'S':
        Serial.print("imakarazyunkai\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("imakarazyunkainihairuyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
      
      case 'T':
        Serial.print("keibihazimeruyo\n");  
        Wire.beginTransmission(0x2E); //接続(接続先はICにデフォルトで設定されてる)
        Wire.write("keibihazimeruyo");    //送るデータ
        Wire.write("\r");             //改行コード  
        Wire.endTransmission();       //終了
        delay(300);
        break;
        
      case 'V':
        Serial.print("ALL LED OFF\n");
        digitalWrite(LED1, LOW);
        digitalWrite(LED2, LOW);
        digitalWrite(LED3, LOW);
        break;
      
      case 'U':
        for(int n=0; n<(sizeof(ANIM_1_TOP)/sizeof(int));n++){
          TEMP_LED[0]=ANIM_1_TOP[n];
          TEMP_LED[1]=ANIM_1_MID[n];
          TEMP_LED[2]=ANIM_1_BOT[n];
          DynaDrive(TEMP_LED); //配列の先頭のポインタのみ与えられる。
          AllOFF();
        }
        for(int n=0; n<(sizeof(ANIM_2_TOP)/sizeof(int));n++){
          TEMP_LED[0]=ANIM_2_TOP[n];
          TEMP_LED[1]=ANIM_2_MID[n];
          TEMP_LED[2]=ANIM_2_BOT[n];
          DynaDrive(TEMP_LED); //配列の先頭のポインタのみ与えられる。
          AllOFF();
        }
        break;
      //*****************************************
      

      
    }
    
 
        
    //switch case文で処理をする
    Serial.write(input);  //シリアルモニタに受信した1文字を表示する
    Serial.write("\n");   //シリアルモニタに改行を表示
  }
  else{
   //何もしない 
  }
  
}


//射出機構発射
void pair_eyes_go(int pwm, int sec){
  digitalWrite(motorA, HIGH);
  digitalWrite(motorB, LOW);
  if(pwm > 0) analogWrite(PWM_mot, pwm);  //PWMが0でないときにモーターを駆動させる
  delay(sec);  //secの秒数機構を発射し続ける
}

//射出機構収納
void pair_eyes_back(int pwm, int sec){
  digitalWrite(motorA, LOW);
  digitalWrite(motorB, HIGH);
  if(pwm > 0) analogWrite(PWM_mot, pwm);  //PWMが0でないときにモーターを駆動させる
  delay(sec);  //secの秒数機構を発射し続ける
}

//モーターをストップさせる
void motor_stop(int sec){
  digitalWrite(motorA, LOW);
  digitalWrite(motorB, LOW);
  delay(sec);  //secの秒数モーターがストップする 
}



